==> spip_3.2.11.orig.tar.xz: plugins-dist/mots/lang/mots_es.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/mots?lang_cible=es
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// A
	'avis_conseil_selection_mot_cle' => '<b>Grupo importante:</b> Se aconseja firmemente seleccionar una palabra clave de este grupo.',
	'avis_doublon_mot_cle' => 'Ya existe una palabra con ese título. ¿Está seguro de querer crear el mismo?',

	// B
	'bouton_checkbox_qui_attribue_mot_cle_administrateurs' => 'administradores del sitio',
	'bouton_checkbox_qui_attribue_mot_cle_redacteurs' => 'redactores',
	'bouton_checkbox_qui_attribue_mot_cle_visiteurs' => 'visitantes del sitio púbico, cuando se expresan en los foros públicos.',

	// C
	'creer_et_associer_un_mot' => 'Crear y asociar una palabra clave',

	// I
	'icone_creation_groupe_mots' => 'Crear un nuevo grupo de palabras',
	'icone_creation_mots_cles' => 'Crear una nueva palabra clave',
	'icone_modif_groupe_mots' => 'Modificar este grupo de palabras',
	'icone_modifier_mot' => 'Modificar esta palabra clave',
	'icone_mots_cles' => 'Palabras clave',
	'icone_supprimer_groupe_mots' => 'Eliminar este grupo',
	'icone_voir_groupe_mots' => 'Ver este grupo de palabras',
	'icone_voir_tous_mots_cles' => 'Ver todas las palabras clave',
	'info_1_groupe_mots' => '1 grupo de palabras',
	'info_articles_lies_mot' => 'Los artículos ligados a esta palabra clave',
	'info_aucun_groupe_mots' => 'Ningún grupo de palabras',
	'info_aucun_mot_cle' => 'Ninguna palabra clave',
	'info_changer_nom_groupe' => 'Cambiar el nombre de este grupo',
	'info_creation_mots_cles' => 'Crear y configurar las palabras clave del sitio',
	'info_dans_groupe' => 'En el grupo',
	'info_delet_mots_cles' => 'Pediste la supresión de la palabra clave
<b>@titre_mot@</b> (@type_mot@). Como esta palabra clave está relacionada a 
<b>@texte_lie@</b>, debes confirmar esta decisión:',
	'info_groupe_important' => 'Grupo importante',
	'info_modifier_mot' => 'Modificar la palabra clave:',
	'info_mots_cles' => 'Las palabras clave',
	'info_mots_cles_association' => 'Las palabras clave de este grupo pueden ser asociadas a:',
	'info_nb_groupe_mots' => '@nb@ gropos de palabras',
	'info_oui_suppression_mot_cle' => 'Deseo suprimir esta palabra clave',
	'info_question_mots_cles' => '¿Deseas utilizar las palabras clave en tu sitio?',
	'info_qui_attribue_mot_cle' => 'Las palabras claves de este grupo pueden ser atribuidas por',
	'info_remplacer_mot' => 'Reemplazar "@titre@"',
	'info_retirer_mot' => 'Retirar la palabra',
	'info_retirer_mots' => 'Retirar todas las palabras',
	'info_rubriques_liees_mot' => 'Las secciones ligadas a esta palabra clave',
	'info_selection_un_seul_mot_cle' => 'Sólo se puede seleccionar <b>una palabra</b> a la vez en este grupo.',
	'info_supprimer_mot' => 'eliminar esta palabra',
	'info_titre_mot_cle' => 'Título de la palabra clave',
	'info_un_mot' => 'Una sola palabra a la vez',
	'item_ajout_mots_cles' => 'Autorizar las palabres claves en los foros',
	'item_non_ajout_mots_cles' => 'Impedir la utilización de las palabras clave en los foros',
	'item_non_utiliser_config_groupe_mots_cles' => 'No utilizar la configuración precisa de los grupos de palabras clave',
	'item_non_utiliser_mots_cles' => 'No utilizar las palabras clave',
	'item_utiliser_config_groupe_mots_cles' => 'Utilizar la configuración precisa de los grupos de palabras clave',
	'item_utiliser_mots_cles' => 'Utilizar las palabras clave',

	// L
	'lien_ajouter_mot' => 'Añadir esta palabra clave',
	'logo_groupe' => 'LOGOTIPO DEL GRUPO',
	'logo_mot_cle' => 'LOGO DE LA PALABRA CLAVE',

	// T
	'texte_config_groupe_mots_cles' => '¿Deseas activar la configuración avanzada de palabras clave, indicando, por ejemplo, que se puede seleccionar sólo una palabra por grupo, que un grupo importante, ...?',
	'texte_mots_cles' => 'Las palabras clave permiten crear enlaces temáticos entre los artículos, independientemente de su emplazamiento dentro de las secciones. Puede así enriquecer la navegación de su sitio, incluso utilizar estas propiedades para personalizar la presentación de los artículos dentro de sus esqueletos.',
	'texte_mots_cles_dans_forum' => '¿Quiere permitir el uso de palabras clave que puedan seleccionarse por los visitantes en los foros del sitio público? (Atención: esta opción es relativamente compleja de usar correctamente)',
	'texte_nouveau_mot' => 'Nueva palabra',
	'titre_config_groupe_mots_cles' => 'Configuración de los grupos de palabras clave',
	'titre_gauche_mots_edit' => 'PALABRA NÚMERO:',
	'titre_groupe_mots' => 'Grupo de palabras clave',
	'titre_groupe_mots_numero' => 'GRUPO DE PALABRAS NÚMERO:',
	'titre_groupes_mots' => 'Grupos de palabras claves',
	'titre_mots_cles_dans_forum' => 'Palabras clave en los foros del sitio público',
	'titre_mots_tous' => 'Las palabras clave',
	'titre_nouveau_groupe' => 'Nuevo grupo',
	'titre_objets_lies_mot' => 'Relacionados a esta palabra clave:',
	'titre_page_mots_tous' => 'Palabras clave'
);

==> spip_4.3.8+dfsg.orig.tar.xz: plugins-dist/mots/lang/mots_es.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/mots?lang_cible=es
// ** ne pas modifier le fichier **

return [

	// A
	'avis_conseil_selection_mot_cle' => '<b>Grupo importante:</b> Se aconseja firmemente seleccionar una palabra clave de este grupo.',
	'avis_doublon_mot_cle' => 'Ya existe una palabra con ese título. ¿Está seguro de querer crear el mismo?',

	// B
	'bouton_checkbox_qui_attribue_mot_cle_administrateurs' => 'administradores del sitio',
	'bouton_checkbox_qui_attribue_mot_cle_redacteurs' => 'redactores',
	'bouton_checkbox_qui_attribue_mot_cle_visiteurs' => 'visitantes del sitio púbico, cuando se expresan en los foros públicos.',

	// C
	'creer_et_associer_un_mot' => 'Crear y asociar una palabra clave',

	// I
	'icone_creation_groupe_mots' => 'Crear un nuevo grupo de palabras',
	'icone_creation_mots_cles' => 'Crear una nueva palabra clave',
	'icone_modif_groupe_mots' => 'Modificar este grupo de palabras',
	'icone_modifier_mot' => 'Modificar esta palabra clave',
	'icone_mots_cles' => 'Palabras clave',
	'icone_supprimer_groupe_mots' => 'Eliminar este grupo',
	'icone_voir_groupe_mots' => 'Ver este grupo de palabras',
	'icone_voir_tous_mots_cles' => 'Ver todas las palabras clave',
	'info_1_groupe_mots' => '1 grupo de palabras',
	'info_articles_lies_mot' => 'Los artículos ligados a esta palabra clave',
	'info_aucun_groupe_mots' => 'Ningún grupo de palabras',
	'info_aucun_mot_cle' => 'Ninguna palabra clave',
	'info_changer_nom_groupe' => 'Cambiar el nombre de este grupo',
	'info_creation_mots_cles' => 'Crear y configurar las palabras clave del sitio',
	'info_dans_groupe' => 'En el grupo',
	'info_delet_mots_cles' => 'Pediste la supresión de la palabra clave
<b>@titre_mot@</b> (@type_mot@). Como esta palabra clave está relacionada a 
<b>@texte_lie@</b>, debes confirmar esta decisión:',
	'info_groupe_important' => 'Grupo importante',
	'info_modifier_mot' => 'Modificar la palabra clave:',
	'info_mots_cles' => 'Las palabras clave',
	'info_mots_cles_association' => 'Las palabras clave de este grupo pueden ser asociadas a:',
	'info_nb_groupe_mots' => '@nb@ gropos de palabras',
	'info_oui_suppression_mot_cle' => 'Deseo suprimir esta palabra clave',
	'info_question_mots_cles' => '¿Deseas utilizar las palabras clave en tu sitio?',
	'info_qui_attribue_mot_cle' => 'Las palabras claves de este grupo pueden ser atribuidas por',
	'info_remplacer_mot' => 'Reemplazar "@titre@"',
	'info_retirer_mot' => 'Retirar la palabra',
	'info_retirer_mots' => 'Retirar todas las palabras',
	'info_rubriques_liees_mot' => 'Las secciones ligadas a esta palabra clave',
	'info_selection_un_seul_mot_cle' => 'Sólo se puede seleccionar <b>una palabra</b> a la vez en este grupo.',
	'info_supprimer_mot' => 'eliminar esta palabra',
	'info_titre_mot_cle' => 'Título de la palabra clave',
	'info_un_mot' => 'Una sola palabra a la vez',
	'item_ajout_mots_cles' => 'Autorizar las palabres claves en los foros',
	'item_non_ajout_mots_cles' => 'Impedir la utilización de las palabras clave en los foros',
	'item_non_utiliser_config_groupe_mots_cles' => 'No utilizar la configuración precisa de los grupos de palabras clave',
	'item_non_utiliser_mots_cles' => 'No utilizar las palabras clave',
	'item_utiliser_config_groupe_mots_cles' => 'Utilizar la configuración precisa de los grupos de palabras clave',
	'item_utiliser_mots_cles' => 'Utilizar las palabras clave',

	// L
	'lien_ajouter_mot' => 'Añadir esta palabra clave',
	'logo_groupe' => 'LOGOTIPO DEL GRUPO',
	'logo_mot_cle' => 'LOGO DE LA PALABRA CLAVE',

	// T
	'texte_config_groupe_mots_cles' => '¿Deseas activar la configuración avanzada de palabras clave, indicando, por ejemplo, que se puede seleccionar sólo una palabra por grupo, que un grupo importante, ...?',
	'texte_mots_cles' => 'Las palabras clave permiten crear enlaces temáticos entre los artículos, independientemente de su emplazamiento dentro de las secciones. Puede así enriquecer la navegación de su sitio, incluso utilizar estas propiedades para personalizar la presentación de los artículos dentro de sus esqueletos.',
	'texte_mots_cles_dans_forum' => '¿Quiere permitir el uso de palabras clave que puedan seleccionarse por los visitantes en los foros del sitio público? (Atención: esta opción es relativamente compleja de usar correctamente)',
	'texte_nouveau_mot' => 'Nueva palabra',
	'titre_config_groupe_mots_cles' => 'Configuración de los grupos de palabras clave',
	'titre_gauche_mots_edit' => 'PALABRA NÚMERO:',
	'titre_groupe_mots' => 'Grupo de palabras clave',
	'titre_groupe_mots_numero' => 'GRUPO DE PALABRAS NÚMERO:',
	'titre_groupes_mots' => 'Grupos de palabras claves',
	'titre_mots_cles_dans_forum' => 'Palabras clave en los foros del sitio público',
	'titre_mots_tous' => 'Las palabras clave',
	'titre_nouveau_groupe' => 'Nuevo grupo',
	'titre_objets_lies_mot' => 'Relacionados a esta palabra clave:',
	'titre_page_mots_tous' => 'Palabras clave',
];
